using System;
using System.IO;
using System.Diagnostics;

namespace Docsultant.Samples.Net.Common
{
	/// <summary>
	/// Logger - prints traces to console and
	/// file
	/// </summary>
	public class Logger
	{
		private static String             s_sLogFile;
		private static Stream             s_stmLog;
		private static bool               s_fInitialized = false;

		private static void InternalInit()
		{
			if( !s_fInitialized )
			{
				s_fInitialized = true;
				Trace.AutoFlush = true;
				Trace.Listeners.Clear();
				Trace.Listeners.Add(new TextWriterTraceListener(Console.Out));

				if( s_stmLog==null )
				{
					if( s_sLogFile==null )
						s_sLogFile = AppConfig.getStr("LogFileName", "session.log");
					s_stmLog = new FileStream(s_sLogFile, FileMode.OpenOrCreate | FileMode.Append);
					Trace.Listeners.Add(new TextWriterTraceListener(s_stmLog));
				}
			}
		}

		public static String LogFile
		{
			get{ return s_sLogFile;  }
			set{ s_sLogFile=value; }
		}


		public static void Init()
		{
			InternalInit();
		}

		public static void Log(String s)
		{
			lock(typeof(Logger))
			{
				InternalInit();
				string s2 = DateTime.Now+" "+s;
				Console.WriteLine(s2);
				for(int i=0, l=s2.Length; i<l; i++)
					s_stmLog.WriteByte((byte)s2[i]);
				s_stmLog.WriteByte((byte)'\n');
				s_stmLog.Flush();
			}
		}

		public static void Log(Exception e)
		{
			Log(e.ToString());
		}

		public static void Log(byte[] abData)
		{
			Log(abData, 0, abData.Length);
		}

		public static void Log(byte[] abData, int nStart, int nLen)
		{
			InternalInit();
			s_stmLog.Write(abData, nStart, nLen);
			s_stmLog.WriteByte((byte)'\n');
			s_stmLog.Flush();
		}
	}
}
