using System;
using System.Net;
using System.Net.Sockets;
using System.Threading;
using System.Diagnostics;
using Docsultant.Samples.Net.Common;


namespace Docsultant.Samples.Net.EchoSrv
{
	/// <summary>
	/// EchoThread - thread that echoes socket
	/// </summary>
	class EchoThread
	{
		private TcpClient m_tcp;

		public EchoThread(TcpClient tcp)
		{
			m_tcp = tcp;
			Thread t = new Thread(new ThreadStart(ThreadProc));
			t.Start();
		}

		private void ThreadProc()
		{
			try
			{
				NetworkStream stm = m_tcp.GetStream();
				const int cbBuf = 4096;
				byte[] abBuf = new byte[cbBuf];
				int cbRead = 0;
				while(true)
				{
					cbRead = stm.Read(abBuf, 0, cbBuf);

					if( cbRead>0 )
						stm.Write(abBuf, 0, cbRead);
					else
						break;
				}
			} catch(Exception e)
			{
				Debug.WriteLine(e, "EchoThread");
			}
		}
	}

	/// <summary>
	/// EchoSrv - socket's echo server application
	/// </summary>
	class EchoSrv : TcpListenerThread
	{
		private EchoSrv(int nPort):base(nPort)
		{
		}

		public static void Main()
		{
			Logger.Init();
			EchoSrv srv = new EchoSrv(AppConfig.getInt("Port",5000));
			srv.Start();
		}
	
		public override bool OnAccept(TcpClient tcp)
		{
			EchoThread cli = new EchoThread(tcp);
			return true;
		}

	}
}

